<?php
/**
 * Plugin Name: PhotoJAR: Base
 * Plugin URI: http://www.jarinteractive.com/code/photojar/photojar-base/
 * Description: Provides numerous enhancements to the Wordpress gallery and provides a framework for additional PhotoJAR plugins.
 * Version: 1.0 beta-2
 * Author: James Rantanen
 * Author URI: http://www.jarinteractive.com
 */

/*
    Copyright (C) 2008 James Rantanen (JARinteractive)

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

define('PJ_DEFAULT_CACHE_PATH', dirname(__FILE__).'/cache/');
define('PJ_DEFAULT_CACHE_URL', get_bloginfo('wpurl') . '/wp-content/plugins/' . dirname(plugin_basename(__FILE__)).'/cache/');

define('PJ_CACHE_PATH', get_option('pj_cache_path'));
define('PJ_CACHE_URL', get_option('pj_cache_url'));

define(PJ_STATUS_NONE, 'NONE');
define(PJ_STATUS_IMAGE, 'IMAGE');
define(PJ_STATUS_GALLERY, 'GALLERY');
define(PJ_STATUS_CHILD_GALLERY, 'CHILD_GALLERY');

$pjStatus=PJ_STATUS_NONE;

//improved image resizing & caching
require_once('pj-image-resize.php');
$imageResize= new ImageResize();
add_filter('image_downsize', array($imageResize, 'imageDownsizeFilter'), 1, 3);

//image shortcode
require_once('pj-image-shortcode.php');
$imageShortcode= new ImageShortcode();
add_shortcode('image', array($imageShortcode, 'imageShortcodeHandler'));
if(get_option('pj_insert_image'))
	add_filter('image_send_to_editor', array($imageShortcode, 'generateTagForEditor'), 1, 7);

//Gallery Shortcode Override - Columns & Size
require_once('pj-gallery-shortcode.php');
$galleryShortcode= new GalleryShortcode();
add_shortcode('gallery', array($galleryShortcode, 'galleryShortcodeHandler'));

//Image Linking &
//LightBox, ThickBox, LightView, Etc...
require_once('pj-link-utility.php');
if(get_option('pj_linkto')!='default')
{
	add_filter('attachment_link', array(LinkUtility, 'imageUrlFilter'), 1, 2);
	if(get_option('pj_linkto')!='full')
		add_filter('the_content', array(LinkUtility, 'whateverBox'), 99);
}

//Config Page
function addPhotoJarConfig() 
{
	add_options_page('PhotoJAR', 'PhotoJAR', 10, basename(dirname(__FILE__)).'/pj-options.php');
}
add_action('admin_menu', 'addPhotoJarConfig');

//install
function pjBaseInstall()
{
	if(get_option('pj_linkto')=='')
	{
		update_option('pj_linkto', 'default');
	}
	if(get_option('pj_insert_image')=='')
	{
		update_option('pj_insert_image', 'true');
	}
	if(get_option('pj_gallery_columns')=='')
	{
		update_option('pj_gallery_columns', '3');
	}
	if(get_option('pj_gallery_size')=='')
	{
		update_option('pj_gallery_size', 'thumbnail');
	}
	if(get_option('pj_jpeg_quality')=='')
	{
		update_option('pj_jpeg_quality', '90');
	}
	if(get_option('pj_cache_path')=='')
	{
		update_option('pj_cache_path', PJ_DEFAULT_CACHE_PATH);
	}	
	if(get_option('pj_cache_url')=='')
	{
		update_option('pj_cache_url', PJ_DEFAULT_CACHE_URL);
	}
	if(!@opendir(PJ_CACHE_PATH))
	{
		mkdir(PJ_CACHE_PATH);
	}
	pjClearCache();
}
add_action('activate_'.basename(dirname(__FILE__)).'/pj-base.php', 'pjBaseInstall');

function pjClearCache()
{
	$cache = opendir(PJ_CACHE_PATH);
	while (false !== ($file = readdir($cache))) 
	{
		if ($file != "." && $file != "..") 
		{
			unlink(PJ_CACHE_PATH.$file);
		}
	}
	closedir($cache);
}